==> migrate-textlint-scripts-typescript-1.0.1.tgz: package/README.md <==
# @textlint/migrate-textlint-scripts-typescript [![Build Status](https://travis-ci.org/textlint/migrate-textlint-scripts-typescript.svg?branch=master)](https://travis-ci.org/textlint/migrate-textlint-scripts-typescript)


Migrate [textlint-scripts](https://github.com/textlint/textlint-scripts) to TypeScript version.

## Target

- The user use [textlint-scripts](https://github.com/textlint/textlint-scripts) with JavaScript

## What do migration script?

- Setup [textlint-scripts](https://github.com/textlint/textlint-scripts) with TypeScript
- Install TypeScript DevDependencies
- Setup TypeScript Configuration

## After Migration

You should migrate JavaScript Code to TypeScript code manually.

## Install

Install with [npm](https://www.npmjs.com/):

    npm install @textlint/migrate-textlint-scripts-typescript -g

## Usage

    Usage
      $ npx migrate-textlint-scripts-typescript
 
    Options
      --yarn  Use yarn if it is specified
 
    Examples
      $ npx migrate-textlint-scripts-typescript --yarn

## Changelog

See [Releases page](https://github.com/textlint/migrate-textlint-scripts-typescript/releases).

## Running tests

Install devDependencies and Run `npm test`:

    npm test

## Contributing

Pull requests and stars are always welcome.

For bugs and feature requests, [please create an issue](https://github.com/textlint/migrate-textlint-scripts-typescript/issues).

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D

## Author

- [github/azu](https://github.com/azu)
- [twitter/azu_re](https://twitter.com/azu_re)

## License

MIT © azu

==> migrate-textlint-scripts-typescript-1.1.0.tgz: package/README.md <==
# @textlint/migrate-textlint-scripts-typescript [![Build Status](https://travis-ci.org/textlint/migrate-textlint-scripts-typescript.svg?branch=master)](https://travis-ci.org/textlint/migrate-textlint-scripts-typescript)


Migrate [textlint-scripts](https://github.com/textlint/textlint-scripts) to TypeScript version.

## Target

- The user use [textlint-scripts](https://github.com/textlint/textlint-scripts) with JavaScript

## What do migration script?

- Setup [textlint-scripts](https://github.com/textlint/textlint-scripts) with TypeScript
- Install TypeScript DevDependencies
- Setup TypeScript Configuration

## After Migration

You should migrate JavaScript Code to TypeScript code manually.

## Install

Install with [npm](https://www.npmjs.com/):

    npm install @textlint/migrate-textlint-scripts-typescript -g

## Usage

    Usage
      $ npx @textlint/migrate-textlint-scripts-typescript
 
    Options
      --yarn  Use yarn if it is specified
 
    Examples
      $ npx @textlint/migrate-textlint-scripts-typescript --yarn

## Changelog

See [Releases page](https://github.com/textlint/migrate-textlint-scripts-typescript/releases).

## Running tests

Install devDependencies and Run `npm test`:

    npm test

## Contributing

Pull requests and stars are always welcome.

For bugs and feature requests, [please create an issue](https://github.com/textlint/migrate-textlint-scripts-typescript/issues).

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D

## Author

- [github/azu](https://github.com/azu)
- [twitter/azu_re](https://twitter.com/azu_re)

## License

MIT © azu
